import {
  all,
  contains,
  isNil,
  type,
} from 'ramda';
import { USER_ROLE } from 'chatler-global-constants';


const hasPermission = permissions => p => contains(p, permissions);

export const userHasPermissions = (user, permissions) => {
  if (!user) {
    throw new Error('can not check permissions of undefined user');
  }

  // Chatler admins have access to everything
  if (user.role === USER_ROLE.ADMIN) { return true; }

  if (isNil(user.permissions)) {
    throw new Error('user permissions are nil or undefined');
  }

  if (isNil(permissions)) {
    throw new Error('permissions are nil or undefined');
  }

  if (type(permissions) === 'Array') {
    return all(hasPermission(user.permissions), permissions);
  }

  if (type(permissions) === 'String') {
    return contains(permissions, user.permissions);
  }
}

export const userManagesUser = (user, userId) => {
  if (user.role === USER_ROLE.ADMIN) { return true; }
  // TODO:
  return true;
}
